@@ -1,27 +1,29 @@
-__version__ = "0.0.12"
+__version__ = "0.0.13"
 __all__ = [
-    "defaultchecks",
-    "warningchecks",
     "allchecks",
-    "checkrsa",
-    "checkpubkey",
-    "checkprivkey",
     "checkcrt",
     "checkcsr",
+    "checkjwk",
+    "checkprivkey",
+    "checkpubkey",
+    "checkrsa",
     "checksshpubkey",
+    "defaultchecks",
     "detectandcheck",
     "scanssh",
+    "warningchecks",
 ]
 from .checks import (
-    defaultchecks,
-    warningchecks,
     allchecks,
-    checkrsa,
-    checkpubkey,
-    checkprivkey,
     checkcrt,
     checkcsr,
+    checkprivkey,
+    checkpubkey,
+    checkrsa,
     checksshpubkey,
+    defaultchecks,
     detectandcheck,
+    warningchecks,
 )
+from .jwk import checkjwk
 from .scanssh import scanssh
