@@ -1,7 +1,7 @@
 import hashlib
+import json
 import mmap
 import pathlib
-import json
 import sys
 
 _blmeta = False
@@ -42,7 +42,7 @@ def _checkbl(bldata, s256trunc):
                 "subtest": subtest,
                 "blid": bl_id,
                 "lookup": lhash,
-                "debug": "Truncated Hash: %s" % s256trunc.hex(),
+                "debug": f"Truncated Hash: {s256trunc.hex()}",
             }
         if s256trunc > val:
             fbegin = fmiddle + 1
@@ -87,13 +87,13 @@ def loadextrabl(fpath):
         _blextra.append(mmap.mmap(f.fileno(), 0, prot=mmap.PROT_READ))
 
 
-def urllookup(blid, lhash, type="show"):
+def urllookup(blid, lhash):
     global _blmeta
     try:
         from binary_file_search.BinaryFileSearch import BinaryFileSearch
     except ModuleNotFoundError:
         sys.stderr.write("ERROR: URL lookup failed, needs binary_file_search module\n")
-        return False
+        return None, None
 
     if not _blmeta:
         _loadblmeta()
@@ -105,15 +105,10 @@ def urllookup(blid, lhash, type="show"):
             x = bfs.search(lhash)
     except FileNotFoundError:
         sys.stderr.write("ERROR: lookup.txt not found, run --update-bl-and-urls\n")
-        return False
+        return None, None
     except KeyError:
-        return False
+        return None, None
     d = _blmeta[blid]
     showurl = f"https://github.com/{d['repo']}/blob/{d['path']}/{x[0][1]}"
     rawurl = f"https://raw.githubusercontent.com/{d['repo']}/{d['path']}/{x[0][1]}"
-    if type == "show":
-        return showurl
-    if type == "raw":
-        return rawurl
-    if type == "both":
-        return [showurl, rawurl]
+    return showurl, rawurl
