@@ -1,6 +1,6 @@
-# License: MIT
+# SPDX-License-Identifier: MIT
 # Copyright (c) 2017, CRoCS, EnigmaBridge Ltd.
-# Copyright (c) 2022, Hanno Böck
+# Copyright (c) Hanno Böck
 #
 # Original: https://github.com/crocs-muni/roca
 # Reduced to core functionality by Hanno Böck
@@ -8,7 +8,7 @@
 import gmpy2
 
 
-def roca(element, e=0):
+def roca(element, e=0):  # noqa: ARG001
     generator = 65537
     generator_order = 2454106387091158800
     pp = [16, 81, 25, 7, 11, 13, 17, 23, 29, 37, 41, 53, 83]
@@ -23,7 +23,7 @@ def roca(element, e=0):
         g_dash = gmpy2.powmod(generator, order_div_prime_power, modulus)
         h_dash = gmpy2.powmod(element, order_div_prime_power, modulus)
         found = False
-        for i in range(0, prime_to_power):
+        for i in range(prime_to_power):
             if gmpy2.powmod(g_dash, i, modulus) == h_dash:
                 found = True
                 break
