@@ -1,4 +1,4 @@
-def xzbackdoor(n, e=0):
+def xzbackdoor(n, e=0):  # noqa: ARG001
     byte_len = (n.bit_length() + 7) // 8
     nb = n.to_bytes(byte_len, byteorder="big")
     # if upper bit is set, ASN1 encodes with leading zero byte
