@@ -1,17 +1,19 @@
-import sys
 import argparse
-import signal
-import re
 import json
+import re
+import signal
+import sys
 
+from . import __version__
+from .allkeys import loadextrabl, urllookup
 from .checks import detectandcheck, defaultchecks, allchecks
 from .checks import checkrsa, checkcrt, checksshpubkey, checkpubkey
-from .allkeys import urllookup, loadextrabl
+from .dkim import parsedkim
+from .jwk import checkjwk
 from .scanssh import scanssh
 from .scantls import scantls
 from .update import update_bl
-from .dkim import parsedkim
-from . import __version__
+from .utils import _warnmsg
 
 MAXINPUTSIZE = 10000
 
@@ -33,11 +35,11 @@ def _printresults(key, where, args):
     if "bits" in key:
         kn += f"[{key['bits']}]"
     if key["type"] == "unsupported":
-        print(f"Warning: Unsupported key type, {where}", file=sys.stderr)
+        _warnmsg(f"Unsupported key type, {where}")
     elif key["type"] == "unparseable":
-        print(f"Warning: Unparseable input, {where}", file=sys.stderr)
+        _warnmsg(f"Unparseable input, {where}")
     elif key["type"] == "notfound":
-        print(f"Warning: No key found, {where}", file=sys.stderr)
+        _warnmsg(f"No key found, {where}")
     elif args.verbose or args.all:
         if key["results"] == {}:
             print(f"{kn} key ok, {where}")
@@ -47,9 +49,11 @@ def _printresults(key, where, args):
             sub = f"/{result['subtest']}"
         print(f"{check}{sub} vulnerability, {kn}, {where}")
         if args.url and "lookup" in result:
-            url = urllookup(result["blid"], result["lookup"])
+            url, _ = urllookup(result["blid"], result["lookup"])
             if url:
                 print(url)
+            else:
+                sys.stderr.write("ERROR: URL lookup failed, not found\n")
         if args.verbose and "debug" in result:
             print(result["debug"])
         if args.verbose and "p" in result:
@@ -91,6 +95,7 @@ def runcli():
         action="store_true",
         help="Scan DKIM DNS record (hostnames instead of files)",
     )
+    ap.add_argument("--jwk", action="store_true", help="Scan JSON Web Keys / Key Sets")
     ap.add_argument("-a", "--all", action="store_true", help="Show all keys")
     ap.add_argument(
         "-w",
@@ -100,6 +105,9 @@ def runcli():
     )
     ap.add_argument("-v", "--verbose", action="store_true", help="Verbose output")
     ap.add_argument("-j", "--json", action="store_true", help="JSON output")
+    ap.add_argument(
+        "-q", "--quiet", action="store_true", help="Quiet output (for update commands)"
+    )
     ap.add_argument(
         "-u", "--url", action="store_true", help="Show private key URL if possible"
     )
@@ -146,10 +154,10 @@ def runcli():
         sys.exit("Scan modes and input file modes cannot be combined.")
 
     if args.update_bl_and_urls:
-        update_bl(lookup=True)
+        update_bl(lookup=True, quiet=args.quiet)
         sys.exit()
     if args.update_bl:
-        update_bl()
+        update_bl(quiet=args.quiet)
         sys.exit()
 
     if args.list:
@@ -171,11 +179,10 @@ def runcli():
         for c in userchecks:
             if c not in allchecks:
                 sys.exit(f"{c} is not a valid check")
+    elif args.warnings:
+        userchecks = allchecks.keys()
     else:
-        if args.warnings:
-            userchecks = allchecks.keys()
-        else:
-            userchecks = defaultchecks.keys()
+        userchecks = defaultchecks.keys()
 
     if args.tls:
         ports = [int(p) for p in args.tls_ports.split(",")]
@@ -197,22 +204,45 @@ def runcli():
         try:
             import dns.resolver
         except ModuleNotFoundError:
-            sys.stderr.write("Error: DKIM DNS record scanning needs dnspython\n")
+            sys.stderr.write("ERROR: DKIM DNS record scanning needs dnspython\n")
             sys.exit(1)
         for host in args.infiles:
             try:
                 records = dns.resolver.resolve(host, "TXT").response
-            except dns.resolver.NXDOMAIN:
+            except (dns.resolver.NXDOMAIN, dns.resolver.NoAnswer):
+                _warnmsg(f"No TXT record found, {host}")
                 continue
+            found = False
             for record in records.answer[-1]:
                 dk = b"".join(record.strings).decode()
                 key = parsedkim(dk)
                 if key:
                     r = checkpubkey(key, checks=userchecks)
                     _printresults(r, host, args)
+                    found = True
+            if not found:
+                _warnmsg(f"No DKIM/DomainKeys key in TXT record, {host}")
 
-    if args.ssh or args.tls or args.dkim_dns:
-        sys.exit(1)
+    if args.jwk:
+        for fn in args.infiles:
+            with open(fn) as f:
+                try:
+                    j = json.load(f)
+                except json.decoder.JSONDecodeError:
+                    _warnmsg(f"No valid JSON, {fn}")
+                    continue
+            if isinstance(j, dict) and "kty" in j:
+                r = checkjwk(j, checks=userchecks)
+                _printresults(r, fn, args)
+            elif isinstance(j, dict) and "keys" in j:
+                for k in j["keys"]:
+                    r = checkjwk(k, checks=userchecks)
+                    _printresults(r, fn, args)
+            else:
+                _warnmsg(f"No JWK/JWKS, {fn}")
+
+    if args.ssh or args.tls or args.dkim_dns or args.jwk:
+        sys.exit(0)
 
     for fn in args.infiles:
         if fn == "-":
@@ -223,8 +253,9 @@ def runcli():
             for line in f:
                 count += 1
                 if line.startswith("Modulus="):
-                    line = line[8:]
-                n = int(line, 16)
+                    n = int(line[8:], 16)
+                else:
+                    n = int(line, 16)
                 r = {"type": "rsa", "bits": n.bit_length()}
                 r["results"] = checkrsa(n, checks=userchecks)
                 _printresults(r, f"modulus {n:02x}", args)
